[Checkins] SVN: z3c.vcsync/trunk/src/z3c/vcsync/interfaces.py Update interfaces.

Martijn Faassen faassen at infrae.com
Wed Jul 4 12:48:14 EDT 2007


Log message for revision 77414:
  Update interfaces.
  

Changed:
  U   z3c.vcsync/trunk/src/z3c/vcsync/interfaces.py

-=-
Modified: z3c.vcsync/trunk/src/z3c/vcsync/interfaces.py
===================================================================
--- z3c.vcsync/trunk/src/z3c/vcsync/interfaces.py	2007-07-04 16:31:34 UTC (rev 77413)
+++ z3c.vcsync/trunk/src/z3c/vcsync/interfaces.py	2007-07-04 16:48:13 UTC (rev 77414)
@@ -71,12 +71,14 @@
 class ICheckout(Interface):
     """A version control system checkout.
     """
-    def sync(object, message=''):
+    def sync(state, dt, message=''):
         """Synchronize persistent Python state with remove version control.
+
+        dt is date since when to look for state changes.
         """
         
-    def save(object):
-        """Save root object to filesystem location of checkout.
+    def save(state, dt):
+        """Save state to filesystem location of checkout.
         """
 
     def load(object):



More information about the Checkins mailing list